From 863c01ad4907ad5de8318df33499f709b30ff40c Mon Sep 17 00:00:00 2001
From: zooko <zooko@zooko.com>
Date: Wed, 18 Apr 2007 21:49:00 +0530
Subject: [PATCH] pyfec: rename pyfec to zfec

It turns out that "pyfec" turns off people who aren't Python hackers.
"allmyfec" is too long for a low-level core utility library.
"fec" is too generic (it is already used by Luigi Rizzo's library which this
library is based on, for one thing).

I'm open to other naming suggestions, especially before we widely announce this
library, which I expect will happen within a few days.

darcs-hash:2c05ab5eaee961453b5ff41587cc72d4fd7bb51d
---
 {pyfec => zfec}/COPYING                 |  2 +-
 {pyfec => zfec}/README.txt              | 16 ++++++++--------
 {pyfec => zfec}/TODO                    |  0
 {pyfec => zfec}/bin/fec                 |  2 +-
 {pyfec => zfec}/bin/unfec               |  2 +-
 {pyfec => zfec}/fec/__init__.py         |  6 +++---
 {pyfec => zfec}/fec/_fecmodule.c        |  4 ++--
 {pyfec => zfec}/fec/easyfec.py          |  0
 {pyfec => zfec}/fec/fec.c               |  4 ++--
 {pyfec => zfec}/fec/fec.h               |  4 ++--
 {pyfec => zfec}/fec/filefec.py          |  4 ++--
 {pyfec => zfec}/fec/test/__init__.py    |  0
 {pyfec => zfec}/fec/test/bench_pyfec.py |  4 ++--
 {pyfec => zfec}/fec/test/test_pyfec.py  |  4 ++--
 {pyfec => zfec}/fec/util/__init__.py    |  0
 {pyfec => zfec}/fec/util/argparse.py    |  0
 {pyfec => zfec}/fec/util/fileutil.py    |  0
 {pyfec => zfec}/fec/util/mathutil.py    |  0
 {pyfec => zfec}/fec/util/version.py     |  0
 {pyfec => zfec}/setup.py                |  8 ++++----
 20 files changed, 30 insertions(+), 30 deletions(-)
 rename {pyfec => zfec}/COPYING (99%)
 rename {pyfec => zfec}/README.txt (95%)
 rename {pyfec => zfec}/TODO (100%)
 rename {pyfec => zfec}/bin/fec (98%)
 rename {pyfec => zfec}/bin/unfec (96%)
 rename {pyfec => zfec}/fec/__init__.py (68%)
 rename {pyfec => zfec}/fec/_fecmodule.c (99%)
 rename {pyfec => zfec}/fec/easyfec.py (100%)
 rename {pyfec => zfec}/fec/fec.c (99%)
 rename {pyfec => zfec}/fec/fec.h (97%)
 rename {pyfec => zfec}/fec/filefec.py (99%)
 rename {pyfec => zfec}/fec/test/__init__.py (100%)
 rename {pyfec => zfec}/fec/test/bench_pyfec.py (97%)
 rename {pyfec => zfec}/fec/test/test_pyfec.py (98%)
 rename {pyfec => zfec}/fec/util/__init__.py (100%)
 rename {pyfec => zfec}/fec/util/argparse.py (100%)
 rename {pyfec => zfec}/fec/util/fileutil.py (100%)
 rename {pyfec => zfec}/fec/util/mathutil.py (100%)
 rename {pyfec => zfec}/fec/util/version.py (100%)
 rename {pyfec => zfec}/setup.py (93%)

diff --git a/pyfec/COPYING b/zfec/COPYING
similarity index 99%
rename from pyfec/COPYING
rename to zfec/COPYING
index eb42bd5..d7e9f2a 100644
--- a/pyfec/COPYING
+++ b/zfec/COPYING
@@ -1,4 +1,4 @@
-In addition to the terms of the GNU General Public License, the pyfec package
+In addition to the terms of the GNU General Public License, the zfec package
 also comes with a special added permission that you may delay for up to 12
 months the fulfillment of your obligation under GPL section 2.b to release any
 derived work under this licence.
diff --git a/pyfec/README.txt b/zfec/README.txt
similarity index 95%
rename from pyfec/README.txt
rename to zfec/README.txt
index 237b006..70d1b5b 100644
--- a/pyfec/README.txt
+++ b/zfec/README.txt
@@ -9,13 +9,13 @@ for up to 12 months.
 
 The most widely known example of an erasure code is the RAID-5 algorithm which
 makes it so that in the event of the loss of any one hard drive, the stored
-data can be completely recovered.  The algorithm in the pyfec package has a
+data can be completely recovered.  The algorithm in the zfec package has a
 similar effect, but instead of recovering from the loss of only a single
 element, it can be parameterized to choose in advance the number of elements
 whose loss it can tolerate.
 
 This package is largely based on the old "fec" library by Luigi Rizzo et al.,
-which is a mature and optimized implementation of erasure coding.  The pyfec
+which is a mature and optimized implementation of erasure coding.  The zfec
 package makes several changes from the original "fec" package, including
 addition of the Python API, refactoring of the C API to support zero-copy
 operation, a few clean-ups and micro-optimizations of the core code itself, 
@@ -26,13 +26,13 @@ and the addition of a command-line tool named "fec".
 
 The source is currently available via darcs on the web with the command:
 
-darcs get http://www.allmydata.com/source/pyfec
+darcs get http://www.allmydata.com/source/zfec
 
 More information on darcs is available at http://darcs.net
 
-Please join the pyfec mailing list and submit patches:
+Please join the zfec mailing list and submit patches:
 
-<https://postman.allmydata.com/cgi-bin/mailman/listinfo/pyfec> 
+<https://postman.allmydata.com/cgi-bin/mailman/listinfo/zfec> 
 
 
  * Overview
@@ -172,11 +172,11 @@ the fact that the Python API returns references to inputs when possible.
 
 Returning references to its inputs is efficient since it avoids making an
 unnecessary copy of the data, but if the object which was passed as input is
-mutable and if that object is mutated after the call to pyfec returns, then the
-result from pyfec -- which is just a reference to that same object -- will also
+mutable and if that object is mutated after the call to zfec returns, then the
+result from zfec -- which is just a reference to that same object -- will also
 be mutated.  This subtlety is the price you pay for avoiding data copying.  If
 you don't want to have to worry about this then you can simply use immutable
-objects (e.g. Python strings) to hold the data that you pass to pyfec.
+objects (e.g. Python strings) to hold the data that you pass to zfec.
 
 
  * Utilities
diff --git a/pyfec/TODO b/zfec/TODO
similarity index 100%
rename from pyfec/TODO
rename to zfec/TODO
diff --git a/pyfec/bin/fec b/zfec/bin/fec
similarity index 98%
rename from pyfec/bin/fec
rename to zfec/bin/fec
index 19e7daa..6ff1956 100755
--- a/pyfec/bin/fec
+++ b/zfec/bin/fec
@@ -12,7 +12,7 @@ from fec.util.version import Version
 __version__ = Version("1.0.0a1-0-STABLE")
 
 if '-V' in sys.argv or '--version' in sys.argv:
-    print "pyfec library version: ", fec.__version__
+    print "zfec library version: ", fec.__version__
     print "fec command-line tool version: ", __version__
     sys.exit(0)
   
diff --git a/pyfec/bin/unfec b/zfec/bin/unfec
similarity index 96%
rename from pyfec/bin/unfec
rename to zfec/bin/unfec
index 9d9fcad..0befb6b 100755
--- a/pyfec/bin/unfec
+++ b/zfec/bin/unfec
@@ -13,7 +13,7 @@ from fec.util.version import Version
 __version__ = Version("1.0.0a1-0-STABLE")
 
 if '-V' in sys.argv or '--version' in sys.argv:
-    print "pyfec library version: ", fec.__version__
+    print "zfec library version: ", fec.__version__
     print "fec command-line tool version: ", __version__
     sys.exit(0)
   
diff --git a/pyfec/fec/__init__.py b/zfec/fec/__init__.py
similarity index 68%
rename from pyfec/fec/__init__.py
rename to zfec/fec/__init__.py
index a82d775..42c2646 100644
--- a/pyfec/fec/__init__.py
+++ b/zfec/fec/__init__.py
@@ -1,9 +1,9 @@
 """
-pyfec -- fast forward error correction library with Python interface
+zfec -- fast forward error correction library with Python interface
 
 maintainer web site: U{http://zooko.com/}
 
-pyfec web site: U{http://www.allmydata.com/source/pyfec}
+zfec web site: U{http://www.allmydata.com/source/zfec}
 """
 
 from util.version import Version
@@ -14,7 +14,7 @@ __version__ = Version("1.0.0a1-2-STABLE")
 
 # Please put a URL or other note here which shows where to get the branch of
 # development from which this version grew.
-__sources__ = ["http://www.allmydata.com/source/pyfec",]
+__sources__ = ["http://www.allmydata.com/source/zfec",]
 
 from _fec import Encoder, Decoder, Error
 import filefec
diff --git a/pyfec/fec/_fecmodule.c b/zfec/fec/_fecmodule.c
similarity index 99%
rename from pyfec/fec/_fecmodule.c
rename to zfec/fec/_fecmodule.c
index a4982b1..c437e8b 100644
--- a/pyfec/fec/_fecmodule.c
+++ b/zfec/fec/_fecmodule.c
@@ -1,11 +1,11 @@
 /**
- * pyfec -- fast forward error correction library with Python interface
+ * zfec -- fast forward error correction library with Python interface
  *
  * Copyright (C) 2007 Allmydata, Inc.
  * Author: Zooko Wilcox-O'Hearn
  * mailto:zooko@zooko.com
  *
- * This file is part of pyfec.
+ * This file is part of zfec.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
diff --git a/pyfec/fec/easyfec.py b/zfec/fec/easyfec.py
similarity index 100%
rename from pyfec/fec/easyfec.py
rename to zfec/fec/easyfec.py
diff --git a/pyfec/fec/fec.c b/zfec/fec/fec.c
similarity index 99%
rename from pyfec/fec/fec.c
rename to zfec/fec/fec.c
index dce7706..bf04429 100644
--- a/pyfec/fec/fec.c
+++ b/zfec/fec/fec.c
@@ -1,11 +1,11 @@
 /**
- * pyfec -- fast forward error correction library with Python interface
+ * zfec -- fast forward error correction library with Python interface
  *
  * Copyright (C) 2007 Allmydata, Inc.
  * Author: Zooko Wilcox-O'Hearn
  * mailto:zooko@zooko.com
  *
- * This file is part of pyfec.
+ * This file is part of zfec.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
diff --git a/pyfec/fec/fec.h b/zfec/fec/fec.h
similarity index 97%
rename from pyfec/fec/fec.h
rename to zfec/fec/fec.h
index 2c689c1..360aed3 100644
--- a/pyfec/fec/fec.h
+++ b/zfec/fec/fec.h
@@ -1,11 +1,11 @@
 /**
- * pyfec -- fast forward error correction library with Python interface
+ * zfec -- fast forward error correction library with Python interface
  *
  * Copyright (C) 2007 Allmydata, Inc.
  * Author: Zooko Wilcox-O'Hearn
  * mailto:zooko@zooko.com
  * 
- * This file is part of pyfec.
+ * This file is part of zfec.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
diff --git a/pyfec/fec/filefec.py b/zfec/fec/filefec.py
similarity index 99%
rename from pyfec/fec/filefec.py
rename to zfec/fec/filefec.py
index c8e3258..7a08a19 100644
--- a/pyfec/fec/filefec.py
+++ b/zfec/fec/filefec.py
@@ -1,10 +1,10 @@
-# pyfec -- fast forward error correction library with Python interface
+# zfec -- fast forward error correction library with Python interface
 # 
 # Copyright (C) 2007 Allmydata, Inc.
 # Author: Zooko Wilcox-O'Hearn
 # mailto:zooko@zooko.com
 # 
-# This file is part of pyfec.
+# This file is part of zfec.
 # 
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
diff --git a/pyfec/fec/test/__init__.py b/zfec/fec/test/__init__.py
similarity index 100%
rename from pyfec/fec/test/__init__.py
rename to zfec/fec/test/__init__.py
diff --git a/pyfec/fec/test/bench_pyfec.py b/zfec/fec/test/bench_pyfec.py
similarity index 97%
rename from pyfec/fec/test/bench_pyfec.py
rename to zfec/fec/test/bench_pyfec.py
index afa1dc0..6b86e8c 100644
--- a/pyfec/fec/test/bench_pyfec.py
+++ b/zfec/fec/test/bench_pyfec.py
@@ -1,10 +1,10 @@
-# pyfec -- fast forward error correction library with Python interface
+# zfec -- fast forward error correction library with Python interface
 # 
 # Copyright (C) 2007 Allmydata, Inc.
 # Author: Zooko Wilcox-O'Hearn
 # mailto:zooko@zooko.com
 # 
-# This file is part of pyfec.
+# This file is part of zfec.
 # 
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
diff --git a/pyfec/fec/test/test_pyfec.py b/zfec/fec/test/test_pyfec.py
similarity index 98%
rename from pyfec/fec/test/test_pyfec.py
rename to zfec/fec/test/test_pyfec.py
index 6d282e9..081eecd 100755
--- a/pyfec/fec/test/test_pyfec.py
+++ b/zfec/fec/test/test_pyfec.py
@@ -3,13 +3,13 @@
 # import bindann
 # import bindann.monkeypatch.all
 
-# pyfec -- fast forward error correction library with Python interface
+# zfec -- fast forward error correction library with Python interface
 #
 # Copyright (C) 2007 Allmydata, Inc.
 # Author: Zooko Wilcox-O'Hearn
 # mailto:zooko@zooko.com
 #
-# This file is part of pyfec.
+# This file is part of zfec.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
diff --git a/pyfec/fec/util/__init__.py b/zfec/fec/util/__init__.py
similarity index 100%
rename from pyfec/fec/util/__init__.py
rename to zfec/fec/util/__init__.py
diff --git a/pyfec/fec/util/argparse.py b/zfec/fec/util/argparse.py
similarity index 100%
rename from pyfec/fec/util/argparse.py
rename to zfec/fec/util/argparse.py
diff --git a/pyfec/fec/util/fileutil.py b/zfec/fec/util/fileutil.py
similarity index 100%
rename from pyfec/fec/util/fileutil.py
rename to zfec/fec/util/fileutil.py
diff --git a/pyfec/fec/util/mathutil.py b/zfec/fec/util/mathutil.py
similarity index 100%
rename from pyfec/fec/util/mathutil.py
rename to zfec/fec/util/mathutil.py
diff --git a/pyfec/fec/util/version.py b/zfec/fec/util/version.py
similarity index 100%
rename from pyfec/fec/util/version.py
rename to zfec/fec/util/version.py
diff --git a/pyfec/setup.py b/zfec/setup.py
similarity index 93%
rename from pyfec/setup.py
rename to zfec/setup.py
index bd1321f..7a44bc1 100755
--- a/pyfec/setup.py
+++ b/zfec/setup.py
@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
 # pyfec -- fast forward error correction library with Python interface
 # 
 # Copyright (C) 2007 Allmydata, Inc.
 # Author: Zooko Wilcox-O'Hearn
 # mailto:zooko@zooko.com
 # 
 # This file is part of pyfec.
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -54,13 +54,13 @@ trove_classifiers=[
     "Topic :: System :: Archiving :: Backup", 
     ]
 
-setup(name='pyfec',
+setup(name='zfec',
       version='1.0.0a1',
       summary='Provides a fast C implementation of Reed-Solomon erasure coding with a Python interface.',
       description='Erasure coding is the generation of redundant blocks of information such that if some blocks are lost ("erased") then the original data can be recovered from the remaining blocks.  This package contains an optimized implementation along with a Python interface.',
       author='Zooko O\'Whielacronx',
       author_email='zooko@zooko.com',
-      url='http://www.allmydata.com/source/pyfec',
+      url='http://www.allmydata.com/source/zfec',
       license='GNU GPL',
       platform='Any',
       packages=['fec', 'fec.util', 'fec.test'],
@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
-# pyfec -- fast forward error correction library with Python interface
+# zfec -- fast forward error correction library with Python interface
 # 
 # Copyright (C) 2007 Allmydata, Inc.
@@ -1,12 +1,12 @@
 # mailto:zooko@zooko.com
 # 
-# This file is part of pyfec.
+# This file is part of zfec.
 # 
 # This program is free software; you can redistribute it and/or
-- 
2.45.2